@@ -28,8 +28,6 @@
 #include <ModemManagerQt/GenericTypes>
 #endif
 
-#include <config.h>
-
 
 class Q_DECL_EXPORT Handler : public QObject
 {
@@ -86,9 +84,6 @@ public Q_SLOTS:
     void enableAirplaneMode(bool enable);
     void enableNetworking(bool enable);
     void enableWireless(bool enable);
-#if !NM_CHECK_VERSION(1, 2, 0)
-    void enableWimax(bool enable);
-#endif
     void enableWwan(bool enable);
 
     /**
@@ -112,9 +107,6 @@ private Q_SLOTS:
 #endif
 
 private:
-#if !NM_CHECK_VERSION(1, 2, 0)
-    bool m_tmpWimaxEnabled;
-#endif
     bool m_tmpWirelessEnabled;
     bool m_tmpWwanEnabled;
 #if WITH_MODEMMANAGER_SUPPORT
